import math
from microprediction.live.iex import iex_latest_prices


XRAY_TICKERS = [ticker.lower() for ticker in ['A', 'AA', 'AAIC', 'AAN', 'AAP', 'AAT', 'ABBV', 'ABC', 'ABG', 'ABM', 'ABR', 'ABT', 'AC', 'ACA', 'ACC',
                   'ACCO','ACEL','ACI','ACM','ACN','ACP','ACRE','ACV','ADC','ADCT','ADM','ADNT','ADT','ADX',
                   'AEE','AEL','AEM','AEO','AER','AES','AFB','AFG','AFI','AFL','AFT','AG','AGCO','AGD','AGI',
                   'AGM','AGM.A','AGO','AGR','AGRO','AGS','AGX','AHH','AHT','AIF','AIG','AIN','AIO','AIR','AIT',
                   'AIV','AIZ','AJG','AJRD','AJX','AKR','AL','ALB','ALC','ALE','ALEX','ALG','ALK','ALL','ALLE',
                   'ALLY','ALSN','ALTG','ALV','ALX','AM','AMBC','AMC','AMCR','AME','AMG','AMH','AMK','AMN','AMP',
                   'AMPY','AMRC','AMRX','AMT','AMWL','AN','ANET','ANF','ANTM','ANVS','AOD','AON','AOS','AP','APAM',
                   'APD','APG','APH','APLE','APO','APRN','APSG','APTS','APTV','AQN','AQUA','AR','ARC','ARCH','ARCO',
                   'ARDC','ARE','ARES','ARGO','ARI','ARL','ARLO','ARMK','ARNC','AROC','ARR','ARW','ASA','ASAN','ASAQ',
                   'ASB','ASC','ASG','ASGI','ASGN','ASH','ASIX','ASPN','ATCO','ATEN','ATGE','ATI','ATKR','ATO','ATR',
                'ATTO','ATUS','AUY','AVA','AVAN','AVB','AVD','AVK','AVLR','AVNS','AVNT','AVTR','AVY','AVYA','AWF',
                                              'AWI', 'AWK', 'AWP', 'AWR', 'AX', 'AXL', 'AXP', 'AXR', 'AXS', 'AXTA', 'AYI', 'AYX', 'AZEK', 'AZO', 'AZRE', 'AZZ',
                                              'B', 'BA', 'BAC', 'BAH', 'BALY', 'BAM', 'BANC', 'BAP', 'BAX', 'BB', 'BBDC', 'BBN', 'BBW', 'BBY', 'BC', 'BCAT', 'BCC',
                                              'BCE', 'BCO', 'BCSF', 'BCX', 'BDC', 'BDJ', 'BDN', 'BDX', 'BE', 'BEN', 'BEPC', 'BERY', 'BF.A', 'BF.B', 'BFAM', 'BFK', 'BFS',
                                              'BFZ', 'BG', 'BGB', 'BGH', 'BGR', 'BGS', 'BGSF', 'BGT', 'BGX', 'BGY', 'BH', 'BH.A', 'BHC', 'BHE', 'BHK', 'BHLB', 'BHR', 'BHV',
                                              'BHVN', 'BIG', 'BILL', 'BIO', 'BIO.B', 'BIPC', 'BIT', 'BJ', 'BK', 'BKD', 'BKE', 'BKH', 'BKI', 'BKN', 'BKT', 'BKU', 'BLD', 'BLDR',
                                              'BLE', 'BLK', 'BLL', 'BLW', 'BLX', 'BME', 'BMEZ', 'BMI', 'BMO', 'BMY', 'BNED', 'BNL', 'BNS', 'BNY', 'BOE', 'BOH', 'BOOT', 'BORR',
                                              'BOX', 'BR', 'BRBR', 'BRC', 'BRK.A', 'BRK.B', 'BRMK', 'BRO', 'BRT', 'BRX', 'BSIG', 'BSL', 'BST', 'BSTZ', 'BSX', 'BTA', 'BTO', 'BTT',
                                              'BTU', 'BTZ', 'BUI', 'BUR', 'BURL', 'BV', 'BVH', 'BW', 'BWA', 'BWG', 'BWXT', 'BX', 'BXC', 'BXMT', 'BXMX', 'BXP', 'BY', 'BYD', 'BYM',
                                              'BZH', 'C', 'CAAP', 'CABO', 'CACI', 'CADE', 'CAE', 'CAF', 'CAG', 'CAH', 'CAL', 'CALX', 'CARR', 'CARS', 'CAT', 'CATO', 'CB', 'CBH',
                                              'CBRE', 'CBT', 'CBU', 'CBZ', 'CC', 'CCI', 'CCJ', 'CCK', 'CCL', 'CCO', 'CCS', 'CDAY', 'CDE', 'CDR', 'CE', 'CEE', 'CEIX', 'CEM', 'CEN',
                                              'CF', 'CFG', 'CFR', 'CGA', 'CHAA', 'CHCT', 'CHD', 'CHE', 'CHGG', 'CHH', 'CHMI', 'CHN', 'CHRA', 'CHS', 'CHWY', 'CI', 'CIA', 'CIEN',
                                              'CIF', 'CII', 'CIM', 'CIO', 'CIR', 'CIXX', 'CL', 'CLB', 'CLDT', 'CLF', 'CLH', 'CLPR', 'CLR', 'CLS', 'CLW', 'CLX', 'CM', 'CMA', 'CMC',
                                              'CMG', 'CMI', 'CMP', 'CMRE', 'CMS', 'CMU', 'CNA', 'CNC', 'CNHI', 'CNI', 'CNK', 'CNMD', 'CNNE', 'CNO', 'CNP', 'CNQ', 'CNR', 'CNS', 'CNX',
                                              'CO', 'CODI', 'COF', 'COLD', 'COO', 'COP', 'CORR', 'COTY', 'CP', 'CPA', 'CPB', 'CPE', 'CPF', 'CPG', 'CPK', 'CPRI', 'CPS', 'CPT', 'CR',
                                              'CRC', 'CRD.A', 'CRD.B', 'CRHC', 'CRI', 'CRK', 'CRL', 'CRM', 'CRS', 'CRT', 'CSL', 'CSTM', 'CSV', 'CTLT', 'CTO', 'CTR', 'CTRA', 'CTS',
                                              'CTT', 'CTVA', 'CUBE', 'CUBI', 'CULP', 'CURO', 'CUZ', 'CVE', 'CVEO', 'CVI', 'CVNA', 'CVS', 'CVX', 'CW', 'CWEN', 'CWEN.A', 'CWH', 'CWK',
                                              'CWT', 'CXE', 'CXH', 'CXW', 'CYD', 'CYH', 'D', 'DAC', 'DAL', 'DAN', 'DAR', 'DB', 'DBD', 'DBI', 'DBL', 'DCF', 'DCI', 'DCO', 'DD', 'DDD',
                                              'DDF', 'DDS', 'DE', 'DEA', 'DECK', 'DEI', 'DELL', 'DEN', 'DESP', 'DEX', 'DFIN', 'DFP', 'DFS', 'DG', 'DGX', 'DHF', 'DHI', 'DHR', 'DHT',
                                              'DHX', 'DIAX', 'DIN', 'DIS', 'DK', 'DKS', 'DLB', 'DLR', 'DLX', 'DLY', 'DMB', 'DMO', 'DMS', 'DNB', 'DNOW', 'DNP', 'DOC', 'DOOR', 'DOV',
                                              'DOW', 'DPG', 'DPZ', 'DRE', 'DRH', 'DRI', 'DRQ', 'DS', 'DSL', 'DSM', 'DSU', 'DSX', 'DT', 'DTE', 'DTF', 'DUK', 'DVA', 'DVN', 'DX', 'DXC',
                                              'DY', 'DYFN', 'EAF', 'EARN', 'EAT', 'EB', 'EBF', 'EBS', 'ECC', 'ECL', 'ECOM', 'ED', 'EDD', 'EDF', 'EDI', 'EEA', 'EEX', 'EFC', 'EFL', 'EFR',
                                              'EFT', 'EFX', 'EGF', 'EGHT', 'EGO', 'EGP', 'EGY', 'EHC', 'EHI', 'EIC', 'EIG', 'EIX', 'EL', 'ELAN', 'ELF', 'ELS', 'ELVT', 'ELY', 'EMD', 'EME',
                                              'EMF', 'EMN', 'EMO', 'EMR', 'ENB', 'ENPC', 'ENR', 'ENS', 'ENV', 'ENVA', 'ENZ', 'EOD', 'EOG', 'EOI', 'EOS', 'EOT', 'EPAC', 'EPAM', 'EPC', 'EPR',
                                              'EPRT', 'EQC', 'EQD', 'EQH', 'EQR', 'EQS', 'EQT', 'ERF', 'ES', 'ESE', 'ESGC', 'ESI', 'ESNT', 'ESRT', 'ESS', 'ESTC', 'ESTE', 'ETB', 'ETG', 'ETJ',
                                              'ETN', 'ETO', 'ETR', 'ETRN', 'ETV', 'ETW', 'ETX', 'ETY', 'EURN', 'EVA', 'EVC', 'EVF', 'EVG', 'EVH', 'EVN', 'EVR', 'EVRG', 'EVRI', 'EVT',
                                              'EVTC', 'EW', 'EXD', 'EXG', 'EXK', 'EXP', 'EXPR', 'EXR', 'EXTN', 'F', 'FAF', 'FAM', 'FBC', 'FBHS', 'FBK', 'FBP', 'FC', 'FCF', 'FCN', 'FCPT',
                                              'FCT', 'FCX', 'FDEU', 'FDP', 'FDS', 'FDX', 'FE', 'FEI', 'FEO', 'FET', 'FF', 'FFA', 'FFC', 'FGB', 'FHI', 'FHN', 'FICO', 'FIF', 'FINS', 'FIS',
                                              'FIX', 'FL', 'FLC', 'FLNG', 'FLO', 'FLR', 'FLS', 'FLT', 'FMC', 'FMN', 'FMY', 'FN', 'FNB', 'FND', 'FNF', 'FNV', 'FOE', 'FOF', 'FOR', 'FOUR',
                                              'FPF', 'FPH', 'FPI', 'FPL', 'FR', 'FRA', 'FRC', 'FRO', 'FRT', 'FSD', 'FSK', 'FSLY', 'FSM', 'FSR', 'FSS', 'FST', 'FT', 'FTAI', 'FTCH', 'FTHY',
                                              'FTI', 'FTK', 'FTS', 'FTV', 'FUBO', 'FUL', 'FUN', 'FVRR', 'G', 'GAB', 'GAM', 'GATO', 'GATX', 'GB', 'GBAB', 'GBCI', 'GBL', 'GBLI', 'GBX',
                                              'GCI', 'GCO', 'GCP', 'GCV', 'GD', 'GDDY', 'GDL', 'GDO', 'GDOT', 'GDV', 'GE', 'GEF', 'GEF.B', 'GEO', 'GER', 'GES', 'GF', 'GFF', 'GFL', 'GGG',
                                              'GGT', 'GGZ', 'GHC', 'GHL', 'GHLD', 'GHM', 'GHY', 'GIB', 'GIL', 'GIM', 'GIS', 'GKOS', 'GL', 'GLOB', 'GLT', 'GLW', 'GM', 'GME', 'GMED', 'GMRE',
                                              'GMS', 'GNE', 'GNK', 'GNL', 'GNRC', 'GNT', 'GNW', 'GOAC', 'GOF', 'GOLD', 'GOLF', 'GOOS', 'GPC', 'GPI', 'GPK', 'GPMT', 'GPN', 'GPRK', 'GPS',
                                              'GRBK', 'GRC', 'GRMN', 'GRX', 'GS', 'GSBD', 'GSL', 'GTES', 'GTLS', 'GTN', 'GTN.A', 'GTY', 'GUT', 'GVA', 'GWRE', 'GWW', 'H', 'HAE', 'HAL',
                                              'HASI', 'HBB', 'HBI', 'HBM', 'HCA', 'HCC', 'HCI', 'HD', 'HE', 'HEI', 'HEI.A', 'HEQ', 'HES', 'HESM', 'HFRO', 'HGLB', 'HGV', 'HHC', 'HI',
                                              'HIE', 'HIG', 'HII', 'HIL', 'HIO', 'HIW', 'HIX', 'HL', 'HLF', 'HLI', 'HLIO', 'HLT', 'HLX', 'HMN', 'HNGR', 'HNI', 'HOG', 'HOMB', 'HOV',
                                              'HP', 'HPE', 'HPF', 'HPI', 'HPP', 'HPQ', 'HPS', 'HPX', 'HQH', 'HQL', 'HR', 'HRB', 'HRI', 'HRL', 'HRTG', 'HSC', 'HSY', 'HT',
                                              'HTA', 'HTD', 'HTGC', 'HTH', 'HTY', 'HUBB', 'HUBS', 'HUM', 'HUN', 'HVT', 'HVT.A', 'HWM', 'HXL', 'HY', 'HYB', 'HYI', 'HYLN',
                                              'HYT', 'HZN', 'HZO', 'IAA', 'IAE', 'IAG', 'IBM', 'IBP', 'ICD', 'ICE', 'ICL', 'IDA', 'IDE', 'IDT', 'IEX', 'IFF', 'IFN', 'IFS',
                                              'IGA', 'IGD', 'IGI', 'IGR', 'IGT', 'IHD', 'IHIT', 'IHTA', 'IIF', 'IIIN', 'IIM', 'IIPR', 'IMAX', 'IMPX', 'INAQ', 'INGR', 'INN',
                                              'INSI', 'INSP', 'INSW', 'INT', 'INVH', 'IO', 'IP', 'IPG', 'IPI', 'IPOD', 'IPOF', 'IQI', 'IQV', 'IR', 'IRL', 'IRM', 'IRT', 'ISD',
                                              'IT', 'ITGR', 'ITT', 'ITW', 'IVC', 'IVH', 'IVR', 'IVZ', 'J', 'JBGS', 'JBL', 'JBT', 'JCE', 'JCI', 'JCO', 'JEF', 'JELD', 'JEMD',
                                              'JEQ', 'JFR', 'JGH', 'JHAA', 'JHG', 'JHI', 'JHS', 'JILL', 'JLL', 'JLS', 'JMM', 'JNJ', 'JNPR', 'JOE', 'JOF', 'JPC', 'JPI',
                                              'JPM', 'JPS', 'JPT', 'JQC', 'JRI', 'JRO', 'JRS', 'JSD', 'JWN', 'K', 'KAI', 'KAMN', 'KAR', 'KBH', 'KBR', 'KEN', 'KEX', 'KEY',
                                              'KEYS', 'KF', 'KFS', 'KFY', 'KGC', 'KIM', 'KIO', 'KKR', 'KLR', 'KMB', 'KMF', 'KMI', 'KMPR', 'KMT', 'KMX', 'KN', 'KNSL', 'KNX',
                                              'KO', 'KODK', 'KOP', 'KOS', 'KR', 'KRC', 'KREF', 'KRG', 'KRO', 'KSM', 'KSS', 'KTB', 'KTF', 'KW', 'KWR', 'KYN', 'L', 'LAC',
                                              'LAD', 'LADR', 'LAZ', 'LBRT', 'LC', 'LCI', 'LCII', 'LDOS', 'LDP', 'LEA', 'LEAP', 'LEG', 'LEN', 'LEN.B', 'LEO', 'LEVI',
                                              'LGF.A', 'LGF.B', 'LGI', 'LH', 'LHX', 'LII', 'LIN', 'LL', 'LLY', 'LMND', 'LMT', 'LNC', 'LNN', 'LOW', 'LPG', 'LPI', 'LPX',
                                              'LRN', 'LSI', 'LSPD', 'LTC', 'LTHM', 'LUB', 'LUMN', 'LUV', 'LVS', 'LW', 'LXFR', 'LXP', 'LXU', 'LYB', 'LYV', 'LZB', 'M', 'MA',
                                              'MAA', 'MAC', 'MAIN', 'MAN', 'MANU', 'MAS', 'MATX', 'MAV', 'MAX', 'MAXR', 'MBI', 'MC', 'MCA', 'MCB', 'MCD', 'MCI', 'MCK',
                                              'MCN', 'MCO', 'MCR', 'MCS', 'MCY', 'MD', 'MDC', 'MDT', 'MDU', 'MEC', 'MED', 'MEG', 'MEI', 'MET', 'MFA', 'MFC', 'MFD', 'MFL',
                                              'MFM', 'MFV', 'MG', 'MGA', 'MGF', 'MGM', 'MGP', 'MGU', 'MGY', 'MHD', 'MHF', 'MHI', 'MHK', 'MHN', 'MHO', 'MIN', 'MITT', 'MIY',
                                              'MKC', 'MKC.V', 'MKL', 'MLI', 'MLM', 'MLP', 'MLR', 'MMC', 'MMD', 'MMI', 'MMM', 'MMP', 'MMS', 'MMT', 'MMU', 'MN', 'MNP',
                                              'MNRL', 'MO', 'MOD', 'MODN', 'MOG.A', 'MOG.B', 'MOH', 'MOS', 'MOV', 'MP', 'MPA', 'MPC', 'MPLN', 'MPV', 'MPW', 'MPX', 'MQT',
                                              'MQY', 'MRC', 'MRK', 'MRO', 'MS', 'MSA', 'MSB', 'MSCI', 'MSD', 'MSGE', 'MSGS', 'MSI', 'MSM', 'MSP', 'MTB', 'MTD', 'MTDR',
                                              'MTG', 'MTH', 'MTN', 'MTOR', 'MTR', 'MTRN', 'MTW', 'MTX', 'MTZ', 'MUA', 'MUC', 'MUE', 'MUI', 'MUJ', 'MUR', 'MUSA', 'MUX',
                                              'MVF', 'MVO', 'MVT', 'MWA', 'MX', 'MXE', 'MXF', 'MYC', 'MYD', 'MYE', 'MYI', 'MYJ', 'MYN', 'MYOV', 'NAC', 'NAD', 'NAN', 'NAT',
                                              'NAZ', 'NBB', 'NBHC', 'NBR', 'NC', 'NCA', 'NCLH', 'NCR', 'NCV', 'NCZ', 'NDMO', 'NDP', 'NEA', 'NEE', 'NEM', 'NET', 'NEU',
                                              'NEV', 'NEWR', 'NEX', 'NEXA', 'NFG', 'NFJ', 'NGS', 'NGVC', 'NGVT', 'NHI', 'NI', 'NID', 'NIE', 'NIM', 'NINE', 'NIQ',
                                              'NJR', 'NKE', 'NKG', 'NKX', 'NL', 'NLS', 'NLSN', 'NLY', 'NM', 'NMCO', 'NMI', 'NMS', 'NMT', 'NMZ', 'NNI', 'NNN', 'NNY',
                                              'NOA', 'NOC', 'NOG', 'NOM', 'NOMD', 'NOV', 'NOVA', 'NOW', 'NP', 'NPK', 'NPO', 'NPTN', 'NPV', 'NQP', 'NR', 'NREF', 'NRG',
                                              'NRGX', 'NRK', 'NRZ', 'NS', 'NSA', 'NSC', 'NSL', 'NSP', 'NTB', 'NTG', 'NTP', 'NTR', 'NTST', 'NUE', 'NUO', 'NUS', 'NUV',
                                              'NUW', 'NVG', 'NVGS', 'NVR', 'NVRO', 'NVST', 'NVT', 'NVTA', 'NWN', 'NX', 'NXC', 'NXE', 'NXJ', 'NXN', 'NXP', 'NXRT',
                                              'NYC', 'NYCB', 'NYT', 'NZF', 'O', 'OACB', 'OC', 'OCN', 'ODC', 'OEC', 'OFC', 'OFG', 'OGE', 'OGS', 'OHI', 'OI', 'OIA',
                                              'OII', 'OIS', 'OKE', 'OLN', 'OLP', 'OMC', 'OMF', 'OMI', 'ONTO', 'OOMA', 'OPP', 'OPY', 'OR', 'ORA', 'ORC', 'ORCC',
                                              'ORCL', 'ORI', 'ORN', 'OSG', 'OSH', 'OSK', 'OTIS', 'OUT', 'OVV', 'OXM', 'OXY', 'PACK', 'PAG', 'PAGS', 'PAI', 'PAR',
                                              'PARR', 'PAYC', 'PB', 'PBA', 'PBF', 'PBH', 'PBI', 'PBT', 'PCF', 'PCG', 'PCK', 'PCM', 'PCN', 'PCQ', 'PD', 'PDI',
                                              'PDM', 'PDS', 'PDT', 'PEAK', 'PEB', 'PEG', 'PEI', 'PEN', 'PEO', 'PFD', 'PFE', 'PFGC', 'PFL', 'PFN', 'PFO', 'PFS',
                                              'PFSI', 'PG', 'PGP', 'PGR', 'PGRE', 'PGTI', 'PGZ', 'PH', 'PHD', 'PHK', 'PHM', 'PHR', 'PHT', 'PHX', 'PIAI', 'PII',
                                              'PIM', 'PINE', 'PING', 'PINS', 'PIPP', 'PIPR', 'PJT', 'PK', 'PKE', 'PKG', 'PKI', 'PLAN', 'PLD', 'PLNT', 'PLOW',
                                              'PLTR', 'PLYM', 'PM', 'PMF', 'PML', 'PMM', 'PMO', 'PMT', 'PMVC', 'PMX', 'PNC', 'PNF', 'PNI', 'PNM', 'PNR', 'PNW',
                                              'POR', 'POST', 'PPG', 'PPL', 'PPT', 'PRA', 'PRGO', 'PRI', 'PRLB', 'PRMW', 'PRO', 'PRPB', 'PRTY', 'PRU', 'PSA',
                                              'PSB', 'PSF', 'PSN', 'PSTG', 'PSTH', 'PSTL', 'PSX', 'PTA', 'PTY', 'PUMP', 'PVH', 'PWR', 'PXD', 'PYN', 'PZC',
                                              'PZN', 'QGEN', 'QS', 'QSR', 'QTWO', 'QUAD', 'QUOT', 'R', 'RA', 'RACE', 'RAD', 'RAMP', 'RBA', 'RBAC', 'RC', 'RCI',
                                              'RCL', 'RCS', 'RCUS', 'RDN', 'RE', 'RES', 'REV', 'REVG', 'REX', 'REXR', 'REZI', 'RF', 'RFI', 'RFL', 'RFM',
                                              'RFP', 'RGA', 'RGR', 'RGS', 'RGT', 'RH', 'RHI', 'RHP', 'RIG', 'RIV', 'RJF', 'RKT', 'RL', 'RLGY', 'RLI', 'RLJ',
                                              'RM', 'RMAX', 'RMD', 'RMI', 'RMM', 'RMT', 'RNG', 'RNGR', 'RNP', 'RNR', 'ROG', 'ROK', 'ROL', 'ROP', 'RPM', 'RPT',
                                              'RQI', 'RRC', 'RS', 'RSF', 'RSG', 'RTX', 'RVLV', 'RVT', 'RWT', 'RY', 'RYAM', 'RYI', 'RYN', 'SA', 'SAFE', 'SAH',
                                              'SAIC', 'SAIL', 'SAM', 'SAND', 'SAR', 'SAVE', 'SB', 'SBH', 'SBI', 'SBOW', 'SCCO', 'SCD', 'SCHW', 'SCI', 'SCL',
                                              'SCM', 'SCS', 'SCU', 'SCX', 'SD', 'SDHY', 'SEAS', 'SEE', 'SEM', 'SF', 'SFBS', 'SFE', 'SFL', 'SG', 'SHAK', 'SHO',
                                              'SHOP', 'SHW', 'SI', 'SIG', 'SII', 'SITC', 'SITE', 'SIX', 'SJI', 'SJM', 'SJR', 'SJW', 'SKT', 'SKX', 'SKY', 'SLB',
                                              'SLCA', 'SLF', 'SLG', 'SLQT', 'SM', 'SMAR', 'SMG', 'SMHI', 'SMM', 'SMP', 'SNA', 'SNAP', 'SNDR', 'SNOW', 'SNV',
                                              'SNX', 'SO', 'SOI', 'SON', 'SOR', 'SPB', 'SPCE', 'SPE', 'SPG', 'SPGI', 'SPOT', 'SPR', 'SPXC', 'SPXX', 'SQ', 'SQZ',
                                              'SR', 'SRC', 'SRE', 'SRG', 'SRI', 'SRL', 'SRT', 'SRV', 'SSD', 'SSTK', 'ST', 'STAG', 'STAR', 'STC', 'STE', 'STK',
                                              'STN', 'STNG', 'STON', 'STOR', 'STT', 'STWD', 'STZ', 'STZ.B', 'SU', 'SUI', 'SUM', 'SUP', 'SWCH', 'SWI', 'SWK',
                                              'SWM', 'SWN', 'SWX', 'SWZ', 'SXC', 'SXI', 'SXT', 'SYF', 'SYK', 'SYY', 'SZC', 'T', 'TAC', 'TALO', 'TAP', 'TAP.A',
                                              'TARO', 'TBI', 'TCI', 'TCS', 'TD', 'TDC', 'TDF', 'TDG', 'TDOC', 'TDS', 'TDW', 'TDY', 'TEAF', 'TECK', 'TEI', 'TEL',
                                              'TEN', 'TEX', 'TFC', 'TFII', 'TFX', 'TG', 'TGH', 'TGI', 'TGNA', 'TGT', 'THC', 'THG', 'THO', 'THQ', 'THR', 'THS',
                                              'THW', 'TISI', 'TJX', 'TK', 'TKR', 'TLYS', 'TMHC', 'TMO', 'TMST', 'TMX', 'TNC', 'TNET', 'TNK', 'TNP', 'TOL', 'TPB',
                                              'TPC', 'TPGY', 'TPH', 'TPL', 'TPR', 'TPVG', 'TPX', 'TPZ', 'TR', 'TRC', 'TREC', 'TREX', 'TRGP', 'TRI', 'TRN', 'TRNO',
                                              'TROX', 'TRP', 'TRQ', 'TRTN', 'TRTX', 'TRU', 'TRV', 'TSE', 'TSI', 'TSLX', 'TSN', 'TSQ', 'TT', 'TTC', 'TTI', 'TTP',
                                              'TU', 'TUFN', 'TUP', 'TWI', 'TWLO', 'TWN', 'TWND', 'TWO', 'TWTR', 'TXT', 'TY', 'TYG', 'TYL', 'U', 'UA', 'UAA', 'UBA',
                                              'UBER', 'UBP', 'UBS', 'UDR', 'UE', 'UFI', 'UGI', 'UHS', 'UHT', 'UI', 'UIS', 'UMH', 'UNF', 'UNFI', 'UNH', 'UNM', 'UNP',
                                              'UNVR', 'UPS', 'URI', 'USA', 'USB', 'USFD', 'USM', 'USNA', 'USPH', 'USX', 'UTF', 'UTI', 'UTL', 'UTZ', 'UVE', 'UVV',
                                              'V', 'VAC', 'VAPO', 'VBF', 'VCIF', 'VCV', 'VEC', 'VEEV', 'VEL', 'VET', 'VFC', 'VGI', 'VGM', 'VGR', 'VHC', 'VHI',
                                              'VICI', 'VKQ', 'VLO', 'VLT', 'VMC', 'VMI', 'VMO', 'VMW', 'VNCE', 'VNO', 'VNT', 'VNTR', 'VOYA', 'VPG', 'VPV', 'VRT',
                                              'VRTV', 'VSH', 'VST', 'VSTO', 'VTN', 'VTOL', 'VTR', 'VVI', 'VVNT', 'VVR', 'VVV', 'VYGG', 'VZ', 'W', 'WAB', 'WAL',
                                              'WAT', 'WBS', 'WBT', 'WCC', 'WCN', 'WD', 'WEA', 'WEC', 'WELL', 'WEX', 'WFC', 'WGO', 'WH', 'WHD', 'WHG', 'WHR', 'WIA',
                                              'WIW', 'WK', 'WLK', 'WLL', 'WM', 'WMB', 'WMC', 'WMK', 'WMS', 'WMT', 'WNC', 'WOR', 'WOW', 'WPC', 'WPM', 'WRB', 'WRE',
                                              'WRK', 'WSM', 'WSO', 'WSO.B', 'WSR', 'WST', 'WTI', 'WTM', 'WTRG', 'WTS', 'WTTR', 'WU', 'WWE', 'WWW', 'WY', 'X',
                                              'XFLT', 'XHR', 'XOM', 'XPO', 'XYL', 'Y', 'YELP', 'YETI', 'YEXT', 'YUM', 'YUMC', 'ZBH', 'ZEN', 'ZTR', 'ZTS', 'ZUO', 'ZYME']]

XRAY_NUM = len(XRAY_TICKERS)

XRAY_NAMES = ['r_' + str(k) + '.json' for k, ticker in enumerate(XRAY_TICKERS)]


def iex_scaled_log_xray(api_key:str):
    """
       Retrieve live prices
       api_key: An IEX api key
    """
    sp = iex_latest_prices(tickers=XRAY_TICKERS, api_key=api_key)
    return [1000 * math.log(v) for v in sp]


if __name__=='__main__':
    print(len(XRAY_NAMES))





# IEX stock prices
# You can get your api_key at https://iexcloud.io/
# See https://iexcloud.io/docs/api/#quote
from getjson import getjson


def iex_latest_prices(tickers, api_key:str)->[float]:
    """
        Grab multiple stock prices
        IEX allows only 100 at a time
    """
    if len(tickers)>100:
        tickerlists = [tickers[i:i + 100] for i in range(0, len(tickers), 100)]
        mids = [ iex_latest_prices(tickers=ticks, api_key=api_key) for ticks in tickerlists ]
        mids_flat = [item for sublist in mids for item in sublist]
        return mids_flat
    else:
        symbols = ','.join(tickers)
        paid_url = 'https://cloud.iexapis.com/v1/stock/market/batch?types=price&symbols='+symbols+'&token=' + api_key
        print(paid_url)
        data = getjson(paid_url)
        mids = [ data[ticker.upper()]['price'] for ticker in tickers]
        return mids


if __name__ == '__main__':
    from pprint import pprint
    from getjson import getjson
    from microprediction.config_private import IEX_KEY
    tickers = ['aapl','googl']
    data = iex_latest_prices(tickers=tickers, api_key=IEX_KEY)
    pprint(data)